linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH] coretemp: Recognize Nehalem CPUs
@ 2008-08-13 22:51 Darrick J. Wong
  2008-08-14  1:11 ` Kent Liu
  2008-08-14  7:07 ` [lm-sensors] [PATCH] " Rudolf Marek
  0 siblings, 2 replies; 5+ messages in thread
From: Darrick J. Wong @ 2008-08-13 22:51 UTC (permalink / raw)
  To: Andrew Morton; +Cc: linux-kernel, lm-sensors

Add in the CPUID for Nehalem chips.

Signed-off-by: Darrick J. Wong <djwong@us.ibm.com>
---

 drivers/hwmon/coretemp.c |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)

diff --git a/drivers/hwmon/coretemp.c b/drivers/hwmon/coretemp.c
index 70239ac..9f2e423 100644
--- a/drivers/hwmon/coretemp.c
+++ b/drivers/hwmon/coretemp.c
@@ -416,7 +416,8 @@ static int __init coretemp_init(void)
 		/* check if family 6, models 0xe, 0xf, 0x16, 0x17 */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
-			(c->x86_model == 0x16) || (c->x86_model == 0x17))) {
+			(c->x86_model == 0x16) || (c->x86_model == 0x17) ||
+			(c->x86_model == 0x1A))) {
 
 			/* supported CPU not found, but report the unknown
 			   family 6 CPU */

^ permalink raw reply related	[flat|nested] 5+ messages in thread

* Re: [PATCH] coretemp: Recognize Nehalem CPUs
  2008-08-13 22:51 [PATCH] coretemp: Recognize Nehalem CPUs Darrick J. Wong
@ 2008-08-14  1:11 ` Kent Liu
  2008-08-14  1:36   ` [PATCH v2] " Darrick J. Wong
  2008-08-14  7:07 ` [lm-sensors] [PATCH] " Rudolf Marek
  1 sibling, 1 reply; 5+ messages in thread
From: Kent Liu @ 2008-08-14  1:11 UTC (permalink / raw)
  To: Darrick J. Wong; +Cc: Andrew Morton, linux-kernel, lm-sensors

On Wed, Aug 13, 2008 at 03:51:48PM -0700, Darrick J. Wong wrote:
> Add in the CPUID for Nehalem chips.
> 
> Signed-off-by: Darrick J. Wong <djwong@us.ibm.com>
> ---
> 
>  drivers/hwmon/coretemp.c |    3 ++-
>  1 files changed, 2 insertions(+), 1 deletions(-)
> 
> diff --git a/drivers/hwmon/coretemp.c b/drivers/hwmon/coretemp.c
> index 70239ac..9f2e423 100644
> --- a/drivers/hwmon/coretemp.c
> +++ b/drivers/hwmon/coretemp.c
> @@ -416,7 +416,8 @@ static int __init coretemp_init(void)
>  		/* check if family 6, models 0xe, 0xf, 0x16, 0x17 */
This comment should be updated as well to include 0x1A.
>  		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
>  		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
> -			(c->x86_model == 0x16) || (c->x86_model == 0x17))) {
> +			(c->x86_model == 0x16) || (c->x86_model == 0x17) ||
> +			(c->x86_model == 0x1A))) {
>  
>  			/* supported CPU not found, but report the unknown
>  			   family 6 CPU */
> --
> To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
> the body of a message to majordomo@vger.kernel.org
> More majordomo info at  http://vger.kernel.org/majordomo-info.html
> Please read the FAQ at  http://www.tux.org/lkml/
> 

^ permalink raw reply	[flat|nested] 5+ messages in thread

* [PATCH v2] coretemp: Recognize Nehalem CPUs
  2008-08-14  1:11 ` Kent Liu
@ 2008-08-14  1:36   ` Darrick J. Wong
  0 siblings, 0 replies; 5+ messages in thread
From: Darrick J. Wong @ 2008-08-14  1:36 UTC (permalink / raw)
  To: Kent Liu; +Cc: Andrew Morton, linux-kernel, lm-sensors

Add in the CPUID for Nehalem chips.

Signed-off-by: Darrick J. Wong <djwong@us.ibm.com>
---

 drivers/hwmon/coretemp.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/drivers/hwmon/coretemp.c b/drivers/hwmon/coretemp.c
index 70239ac..93c1722 100644
--- a/drivers/hwmon/coretemp.c
+++ b/drivers/hwmon/coretemp.c
@@ -413,10 +413,11 @@ static int __init coretemp_init(void)
 	for_each_online_cpu(i) {
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
 		/* check if family 6, models 0xe, 0xf, 0x16, 0x17 */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
-			(c->x86_model == 0x16) || (c->x86_model == 0x17))) {
+			(c->x86_model == 0x16) || (c->x86_model == 0x17) ||
+			(c->x86_model == 0x1A))) {
 
 			/* supported CPU not found, but report the unknown
 			   family 6 CPU */

^ permalink raw reply related	[flat|nested] 5+ messages in thread

* Re: [lm-sensors] [PATCH] coretemp: Recognize Nehalem CPUs
  2008-08-13 22:51 [PATCH] coretemp: Recognize Nehalem CPUs Darrick J. Wong
  2008-08-14  1:11 ` Kent Liu
@ 2008-08-14  7:07 ` Rudolf Marek
  2008-08-18 17:56   ` Rudolf Marek
  1 sibling, 1 reply; 5+ messages in thread
From: Rudolf Marek @ 2008-08-14  7:07 UTC (permalink / raw)
  To: djwong; +Cc: Andrew Morton, linux-kernel, lm-sensors

Hi Darrick,

Please update the Documentation too. I have patch for the Intel Atom, but this 
one seems trivial, so lets push this one first.

Thanks,
Rudolf

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [lm-sensors] [PATCH] coretemp: Recognize Nehalem CPUs
  2008-08-14  7:07 ` [lm-sensors] [PATCH] " Rudolf Marek
@ 2008-08-18 17:56   ` Rudolf Marek
  0 siblings, 0 replies; 5+ messages in thread
From: Rudolf Marek @ 2008-08-18 17:56 UTC (permalink / raw)
  To: djwong; +Cc: linux-kernel, lm-sensors

Hi again,

Please can you respin the patch with the documentation update, so I can post 
updated patch to add Atom to coretemp?

Also please fix the 0x1A to 0x1a.

Thanks,

Rudolf

^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2008-08-18 17:56 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -413,10 +413,11 @@ static int __init coretemp_init(void)
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
-		/* check if family 6, models 0xe, 0xf, 0x16, 0x17 */
+		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
2008-08-13 22:51 [PATCH] coretemp: Recognize Nehalem CPUs Darrick J. Wong
2008-08-14  1:11 ` Kent Liu
2008-08-14  1:36   ` [PATCH v2] " Darrick J. Wong
2008-08-14  7:07 ` [lm-sensors] [PATCH] " Rudolf Marek
2008-08-18 17:56   ` Rudolf Marek

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).